==> chaosmesh-model-6.3.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/RecordFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RecordFluentImpl<A extends RecordFluent<A>> extends BaseFluent<A> implements RecordFluent<A>{
  public RecordFluentImpl() {
  }
  public RecordFluentImpl(Record instance) {
    this.withId(instance.getId()); 
    this.withPhase(instance.getPhase()); 
    this.withSelectorKey(instance.getSelectorKey()); 
  }
  private String id;
  private String phase;
  private String selectorKey;
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public Boolean hasId() {
    return this.id != null;
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public Boolean hasPhase() {
    return this.phase != null;
  }
  public String getSelectorKey() {
    return this.selectorKey;
  }
  public A withSelectorKey(String selectorKey) {
    this.selectorKey=selectorKey; return (A) this;
  }
  public Boolean hasSelectorKey() {
    return this.selectorKey != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RecordFluentImpl that = (RecordFluentImpl) o;
    if (id != null ? !id.equals(that.id) :that.id != null) return false;
    if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
    if (selectorKey != null ? !selectorKey.equals(that.selectorKey) :that.selectorKey != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(id,  phase,  selectorKey,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (selectorKey != null) { sb.append("selectorKey:"); sb.append(selectorKey); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/RecordFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RecordFluentImpl<A extends RecordFluent<A>> extends BaseFluent<A> implements RecordFluent<A>{
  public RecordFluentImpl() {
  }
  public RecordFluentImpl(Record instance) {
    if (instance != null) {
      this.withId(instance.getId());
      this.withPhase(instance.getPhase());
      this.withSelectorKey(instance.getSelectorKey());
    }
  }
  private String id;
  private String phase;
  private String selectorKey;
  public String getId() {
    return this.id;
  }
  public A withId(String id) {
    this.id=id; return (A) this;
  }
  public Boolean hasId() {
    return this.id != null;
  }
  public String getPhase() {
    return this.phase;
  }
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  public Boolean hasPhase() {
    return this.phase != null;
  }
  public String getSelectorKey() {
    return this.selectorKey;
  }
  public A withSelectorKey(String selectorKey) {
    this.selectorKey=selectorKey; return (A) this;
  }
  public Boolean hasSelectorKey() {
    return this.selectorKey != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RecordFluentImpl that = (RecordFluentImpl) o;
    if (!java.util.Objects.equals(id, that.id)) return false;

    if (!java.util.Objects.equals(phase, that.phase)) return false;

    if (!java.util.Objects.equals(selectorKey, that.selectorKey)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(id,  phase,  selectorKey,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (id != null) { sb.append("id:"); sb.append(id + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (selectorKey != null) { sb.append("selectorKey:"); sb.append(selectorKey); }
    sb.append("}");
    return sb.toString();
  }
  
}
